@@ -65,3 +65,7 @@ def is_positive_definite(x: np.ndarray) -> bool:
     except Exception:
         return False
 
+
+@njit
+def is_positive_semidefinite(x: np.ndarray, tol=1e-12) -> bool:
+    return np.all(np.linalg.eigvalsh(x) > -tol)
